==> lein-template-0.1.0.jar: leiningen/new/kit/src/clj/core.clj <==
(ns <<ns-name>>.core
  (:require
    [clojure.tools.logging :as log]
    [integrant.core :as ig]
    [<<ns-name>>.config :as config]
    [<<ns-name>>.env :refer [defaults]]

    ;; Edges <% if redis? %>
    [kit.edge.cache.redis]<% endif %> <% if xtdb? %>
    [kit.edge.db.xtdb]<% endif %> <% if sql? %>
    [kit.edge.db.sql]
    [kit.edge.db.postgres]<% endif %> <% if hato? %>
    [kit.edge.http.hato]<% endif %> <% if quartz? %>
    [kit.edge.scheduling.quartz]<% endif %> <% if selmer? %>
    [kit.edge.templating.selmer]<% endif %> <% if metrics? %>
    [kit.edge.utils.metrics]<% endif %> <% if repl? %>
    [kit.edge.utils.repl]<% endif %>
    [kit.edge.server.undertow]
    [<<ns-name>>.web.handler]

    ;; Routes
    [<<ns-name>>.web.routes.api]
    )
  (:gen-class))

;; log uncaught exceptions in threads
(Thread/setDefaultUncaughtExceptionHandler
  (reify Thread$UncaughtExceptionHandler
    (uncaughtException [_ thread ex]
      (log/error {:what :uncaught-exception
                  :exception ex
                  :where (str "Uncaught exception on" (.getName thread))}))))

(defonce system (atom nil))

(defn stop-app []
  ((or (:stop defaults) (fn [])))
  (some-> (deref system) (ig/halt!))
  (shutdown-agents))

(defn start-app [& [params]]
  ((or (:start params) (:start defaults) (fn [])))
  (->> (config/system-config (or (:opts params) (:opts defaults) {}))
       (ig/prep)
       (ig/init)
       (reset! system))
  (.addShutdownHook (Runtime/getRuntime) (Thread. stop-app)))

(defn -main [& _]
  (start-app))

==> lein-template-0.1.5.jar: leiningen/new/kit/src/clj/core.clj <==
(ns <<ns-name>>.core
  (:require
    [clojure.tools.logging :as log]
    [integrant.core :as ig]
    [<<ns-name>>.config :as config]
    [<<ns-name>>.env :refer [defaults]]

    ;; Edges <% if redis? %>
    [kit.edge.cache.redis]<% endif %> <% if xtdb? %>
    [kit.edge.db.xtdb]<% endif %> <% if sql? %>
    [kit.edge.db.sql]
    [kit.edge.db.postgres]<% endif %> <% if hato? %>
    [kit.edge.http.hato]<% endif %> <% if quartz? %>
    [kit.edge.scheduling.quartz]<% endif %> <% if selmer? %>
    [kit.edge.templating.selmer]<% endif %> <% if metrics? %>
    [kit.edge.utils.metrics]<% endif %> <% if repl? %>
    [kit.edge.utils.repl]<% endif %> <% if nrepl? %>
    [kit.edge.utils.nrepl]<% endif %>
    [kit.edge.server.undertow]
    [<<ns-name>>.web.handler]

    ;; Routes
    [<<ns-name>>.web.routes.api]
    )
  (:gen-class))

;; log uncaught exceptions in threads
(Thread/setDefaultUncaughtExceptionHandler
  (reify Thread$UncaughtExceptionHandler
    (uncaughtException [_ thread ex]
      (log/error {:what :uncaught-exception
                  :exception ex
                  :where (str "Uncaught exception on" (.getName thread))}))))

(defonce system (atom nil))

(defn stop-app []
  ((or (:stop defaults) (fn [])))
  (some-> (deref system) (ig/halt!))
  (shutdown-agents))

(defn start-app [& [params]]
  ((or (:start params) (:start defaults) (fn [])))
  (->> (config/system-config (or (:opts params) (:opts defaults) {}))
       (ig/prep)
       (ig/init)
       (reset! system))
  (.addShutdownHook (Runtime/getRuntime) (Thread. stop-app)))

(defn -main [& _]
  (start-app))
